# Bosnian CSS Preprocessor

A plugin to translate CSS properties and values from Bosnian to English.

## Installation

### Global Installation

Install the package globally to use the CLI tool:

```bash
npm install -g bosnian-css-preprocessor
```

You can use the CLI tool to process your CSS files from Bosnian to English:

```bash
bosnian-css-preprocessor <input file> <output file>
```

e.g.

```bash
bosnian-css-preprocessor src/styles.css dist/styles.css
```

### Live Reloading

To automatically process your CSS files , you can use the built-in watcher.

```json
{
  "scripts": {
    "translate-css": "bosnian-css-preprocessor src/styles_bosnian.css src/styles.css"
  }
}
```

Then run:

```bash
npm run translate-css
```

### Writing CSS

You can write your CSS files using Bosnian terms, and they will be translated by the plugin:

```css
/* src/styles.css */
body {
  boja: crvena;
  pozadina: plava;
}
```

Will be translated to:

```css
/* src/styles.css */
body {
  color: red;
  background: blue;
}
```

## Supported Properties

```JSON
{
  "--*": "--*",
  "akcija-dodirom": "touch-action",
  "alternativne-varijante-fonta": "font-variant-alternates",
  "alternativni": "alt",
  "animacija": "animation",
  "automatske-kolone-mreže": "grid-auto-columns",
  "automatski-protok-mreže": "grid-auto-flow",
  "automatski-redovi-mreže": "grid-auto-rows",
  "azimut": "azimuth",
  "bogatstvo": "richness",
  "boja": "color",
  "boja-dekoracije-teksta": "text-decoration-color",
  "boja-desne-granice": "border-right-color",
  "boja-dna-granice": "border-bottom-color",
  "boja-gornje-granice": "border-top-color",
  "boja-granice": "border-color",
  "boja-konture": "outline-color",
  "boja-lijeve-granice": "border-left-color",
  "boja-naglaska-teksta": "text-emphasis-color",
  "boja-osvjetljenja": "lighting-color",
  "boja-poplave": "flood-color",
  "boja-pozadine": "background-color",
  "boja-pravila-kolone": "column-rule-color",
  "boja-zaustavljanja": "stop-color",
  "broj-kolona": "column-count",
  "broj-ponavljanja-animacije": "animation-iteration-count",
  "broj-reprodukcija-marquee": "marquee-play-count",
  "brzina-glasa": "voice-rate",
  "brzina-govora": "speech-rate",
  "brzina-marquee": "marquee-speed",
  "crte": "hyphens",
  "crtkanje-udara": "stroke-dasharray",
  "dekoracija-teksta": "text-decoration",
  "desna-granica": "border-right",
  "desna-margina": "margin-right",
  "desno": "right",
  "dno": "bottom",
  "dno-granice": "border-bottom",
  "dominantna-osnovna-linija": "dominant-baseline",
  "donja-margina": "margin-bottom",
  "donji-desni-radijus-granice": "border-bottom-right-radius",
  "donji-lijevi-radijus-granice": "border-bottom-left-radius",
  "elevacija": "elevation",
  "filter": "filter",
  "filteri-interpolacije-boje": "color-interpolation-filters",
  "font": "font",
  "fragment-regije": "region-fragment",
  "funkcija-vremena-animacije": "animation-timing-function",
  "funkcija-vremena-prijelaza": "transition-timing-function",
  "glasnoća-glasa": "voice-volume",
  "gore": "top",
  "gornja-granica": "border-top",
  "gornja-margina": "margin-top",
  "gornji-desni-radijus-granice": "border-top-right-radius",
  "gornji-lijevi-radijus-granice": "border-top-left-radius",
  "govor": "speak",
  "govori-broj": "speak-numeral",
  "govori-interpunkciju": "speak-punctuation",
  "govori-kao": "speak-as",
  "govori-naslov": "speak-header",
  "granica": "border",
  "graničnik-udara": "stroke-miterlimit",
  "horizontalna-orijentacija-glypha": "glyph-orientation-horizontal",
  "hoće-se-promijeniti": "will-change",
  "ikona": "icon",
  "ime": "ime",
  "ime-animacije": "animation-name",
  "interpolacija-boje": "color-interpolation",
  "iscjedak": "bleed",
  "isječak": "clip",
  "isječak-kutije-maske": "mask-box-slice",
  "isječak-maske": "mask-clip",
  "isječak-pozadine": "background-clip",
  "isječak-slike-granice": "border-image-slice",
  "ispuna": "padding",
  "ispuna-desno": "padding-right",
  "ispuna-dno": "padding-bottom",
  "ispuna-gore": "padding-top",
  "ispuna-kolone": "column-fill",
  "ispuna-lijevo": "padding-left",
  "ispuna-oblika": "shape-padding",
  "izbacivanje-desnog-markera": "marker-knockout-right",
  "izbacivanje-lijevog-markera": "marker-knockout-left",
  "izgled-tabele": "table-layout",
  "izolacija": "isolation",
  "izvor-kutije-maske": "mask-box-source",
  "izvor-maske": "mask-origin",
  "izvor-perspektive": "perspective-origin",
  "izvor-pozadine": "background-origin",
  "izvor-slike-granice": "border-image-source",
  "izvor-transformacije": "transform-origin",
  "kašnjenje-animacije": "animation-delay",
  "kašnjenje-prijelaza": "transition-delay",
  "kerning": "kerning",
  "kerning-fonta": "font-kerning",
  "kolona-mreže": "grid-column",
  "kolone": "columns",
  "kolone-predloška-mreže": "grid-template-columns",
  "kombinacija-uspravnog-teksta": "text-combine-upright",
  "kontura": "outline",
  "koordinata-snimanja-scroll-a": "scroll-snap-coordinate",
  "korekcija-boje": "color-correction",
  "kraj-kolone-mreže": "grid-column-end",
  "kraj-linije-udara": "stroke-linecap",
  "kraj-markera": "marker-end",
  "kraj-pomaka": "offset-end",
  "kraj-reda-mreže": "grid-row-end",
  "kroz-omotač": "wrap-through",
  "kutija-maske": "mask-box",
  "kutija-transformacije": "transform-box",
  "labava-linija": "line-slack",
  "ligature-fonta": "font-variant-ligatures",
  "lijeva-granica": "border-left",
  "lijeva-margina": "margin-left",
  "lijevo": "left",
  "linija-dekoracije-teksta": "text-decoration-line",
  "maksimalna-visina": "max-height",
  "maksimalna-širina": "max-width",
  "maksimalne-linije": "max-lines",
  "margina": "margin",
  "margina-oblika": "shape-margin",
  "marker": "marker",
  "maska": "mask",
  "minimalna-visina": "min-height",
  "minimalna-širina": "min-width",
  "mreža": "grid",
  "mreža-linija": "line-grid",
  "nadjačavanje-jezika-fonta": "font-language-override",
  "naglasak-teksta": "text-emphasis",
  "navigacija-desno": "nav-right",
  "navigacija-dolje": "nav-down",
  "navigacija-gore": "nav-up",
  "navigacija-lijevo": "nav-left",
  "navigacijski-indeks": "nav-index",
  "navodnici": "quotes",
  "način-ime": "ime-mode",
  "način-miješanja": "mix-blend-mode",
  "način-miješanja-pozadine": "background-blend-mode",
  "način-pisanja": "writing-mode",
  "neprozirnost": "opacity",
  "nivo-knjige": "bookmark-level",
  "numeričke-varijante-fonta": "font-variant-numeric",
  "odloži-kolonu": "float-defer-column",
  "odloži-stranicu": "float-defer-page",
  "odmor": "rest",
  "odmor-poslije": "rest-after",
  "odmor-prije": "rest-before",
  "odredište-snimanja-scroll-a": "scroll-snap-destination",
  "ograničenje-linija-razdvajanja": "hyphenate-limit-lines",
  "ograničenje-zadnjeg-razdvajanja": "hyphenate-limit-last",
  "ograničenje-znakova-razdvajanja": "hyphenate-limit-chars",
  "omogući-pozadinu": "enable-background",
  "omotaj-plivajući": "float-wrap",
  "omotaj-riječ": "word-wrap",
  "omotaj-savijanje": "flex-wrap",
  "omotaj-tekst": "text-wrap",
  "opravdaj-sadržaj": "justify-content",
  "opravdaj-sebe": "justify-self",
  "opravdaj-stavke": "justify-items",
  "opravdaj-tekst": "text-justify",
  "orijentacija-slike": "image-orientation",
  "orijentacija-teksta": "text-orientation",
  "osnova-savijanja": "flex-basis",
  "osnovna-linija-poravnanja": "alignment-baseline",
  "oznaka-knjige": "bookmark-label",
  "oznake": "marks",
  "očisti": "clear",
  "očisti-stranu": "clear-side",
  "pauza": "pause",
  "pauza-poslije": "pause-after",
  "pauza-prije": "pause-before",
  "perspektiva": "perspective",
  "plivajući": "float",
  "podesi-poravnanje": "alignment-adjust",
  "podešavanje-veličine-fonta": "font-size-adjust",
  "podešavanje-veličine-teksta": "text-size-adjust",
  "područja-predloška-mreže": "grid-template-areas",
  "područje-mreže": "grid-area",
  "pokazivač": "cursor",
  "pokazivački-događaji": "pointer-events",
  "politika-fusnote": "footnote-policy",
  "pomak-crtkanja-udara": "stroke-dashoffset",
  "pomak-ime": "ime-offset",
  "pomak-konture": "outline-offset",
  "pomak-osnovne-linije": "baseline-shift",
  "pomak-plivanja": "float-offset",
  "pomak-poslije": "offset-after",
  "pomak-prije": "offset-before",
  "pomoćno-renderiranje": "buffered-rendering",
  "ponavljanje-kutije-maske": "mask-box-repeat",
  "ponavljanje-maske": "mask-repeat",
  "ponavljanje-pozadine": "background-repeat",
  "ponavljanje-slike-granice": "border-image-repeat",
  "ponašanje-scroll-a": "scroll-behavior",
  "popunjavajući-način-animacije": "animation-fill-mode",
  "poravnaj-elemente": "align-items",
  "poravnaj-sadržaj": "align-content",
  "poravnaj-sebe": "align-self",
  "poravnanje-ime": "ime-align",
  "poravnanje-inline-kutije": "inline-box-align",
  "poravnanje-rubina": "ruby-align",
  "poravnanje-svih-teksta": "text-align-all",
  "poravnanje-teksta": "text-align",
  "poravnanje-zadnjeg-teksta": "text-align-last",
  "porodica-fontova": "font-family",
  "porodica-glasa": "voice-family",
  "postavke-funkcija-fonta": "font-feature-settings",
  "postavljanje-brojila": "counter-set",
  "povećanje-brojila": "counter-increment",
  "pozadina": "background",
  "pozicija": "position",
  "pozicija-maske": "mask-position",
  "pozicija-naglaska-teksta": "text-emphasis-position",
  "pozicija-objekta": "object-position",
  "pozicija-podvlačenja-teksta": "text-underline-position",
  "pozicija-pozadine": "background-position",
  "pozicija-rubina": "ruby-position",
  "pozicija-stila-liste": "list-style-position",
  "pozicione-varijante-fonta": "font-variant-position",
  "početak-kolone-mreže": "grid-column-start",
  "početak-kutije-maske": "mask-box-outset",
  "početak-markera": "marker-start",
  "početak-pomaka": "offset-start",
  "početak-reda-mreže": "grid-row-start",
  "početak-slike-granice": "border-image-outset",
  "početna-slova": "initial-letters",
  "prag-slike-oblika": "shape-image-threshold",
  "pravilo-isječka": "clip-rule",
  "pravilo-ispune": "fill-rule",
  "pravilo-kolone": "column-rule",
  "prazan-prostor": "white-space",
  "prazne-ćelije": "empty-cells",
  "predložak-mreže": "grid-template",
  "prekid-iznutra": "break-inside",
  "prekid-poslije": "break-after",
  "prekid-prije": "break-before",
  "prekid-ukrašavanja-okvira": "box-decoration-break",
  "preliv-teksta": "text-overflow",
  "preljev": "overflow",
  "preljev-omotaj": "overflow-wrap",
  "preljev-x": "overflow-x",
  "preljev-y": "overflow-y",
  "prelom-linije": "line-break",
  "prelom-riječi": "word-break",
  "prelom-stranice-iznutra": "page-break-inside",
  "prelom-stranice-poslije": "page-break-after",
  "prelom-stranice-prije": "page-break-before",
  "preskoči-dekoraciju-teksta": "text-decoration-skip",
  "preskoči-naglasak-teksta": "text-emphasis-skip",
  "prijelaz": "transition",
  "prikaz": "display",
  "prikaz-ekstra": "display-extras",
  "prikaz-kutije": "display-box",
  "prikaz-unutra": "display-inside",
  "prikaz-vani": "display-outside",
  "prilagodba-boje": "color-adjust",
  "prilagodba-objekta": "object-fit",
  "pričvršćenje-pozadine": "background-attachment",
  "profil-boje": "color-profile",
  "promijeni-veličinu": "resize",
  "protok-iz": "flow-from",
  "protok-omotača": "wrap-flow",
  "protok-savijanja": "flex-flow",
  "protok-u": "flow-into",
  "prozirnost-ispune": "fill-opacity",
  "prozirnost-poplave": "flood-opacity",
  "prozirnost-udara": "stroke-opacity",
  "prozirnost-zaustavljanja": "stop-opacity",
  "putanja-isječka": "clip-path",
  "radijus-granice": "border-radius",
  "raspon-glasa": "voice-range",
  "raspon-kolone": "column-span",
  "raspon-visine-tona": "pitch-range",
  "rast-savijanja": "flex-grow",
  "rastezanje-fonta": "font-stretch",
  "ravnoteža-glasa": "voice-balance",
  "razmak-granica": "border-spacing",
  "razmak-između-kolona": "column-gap",
  "razmak-riječi": "word-spacing",
  "razmak-slova": "letter-spacing",
  "razmak-teksta": "text-spacing",
  "red-mreže": "grid-row",
  "redoslijed": "order",
  "redoslijed-boje": "paint-order",
  "redovi-predloška-mreže": "grid-template-rows",
  "renderiranje-boje": "color-rendering",
  "renderiranje-oblika": "shape-rendering",
  "renderiranje-slike": "image-rendering",
  "renderiranje-teksta": "text-rendering",
  "reprodukcija-tokom": "play-during",
  "resetovanje-brojila": "counter-reset",
  "rezolucija-slike": "image-resolution",
  "sadržaj": "content",
  "sadrži": "contain",
  "sadrži-liniju-kutije": "line-box-contain",
  "savij": "flex",
  "sažimanje-prostora-teksta": "text-space-collapse",
  "segment-markera": "marker-segment",
  "set-stringova": "string-set",
  "sidro-teksta": "text-anchor",
  "signal": "cue",
  "signal-poslije": "cue-after",
  "signal-prije": "cue-before",
  "sinteza-fonta": "font-synthesis",
  "siročad": "orphans",
  "sjena-okvira": "box-shadow",
  "sjena-teksta": "text-shadow",
  "slika-granice": "border-image",
  "slika-maske": "mask-image",
  "slika-pozadine": "background-image",
  "slika-stila-liste": "list-style-image",
  "smanjenje-savijanja": "flex-shrink",
  "smjer": "direction",
  "smjer-animacije": "animation-direction",
  "smjer-marquee": "marquee-direction",
  "smjer-savijanja": "flex-direction",
  "snimak-linije": "line-snap",
  "snimak-okvira": "box-snap",
  "spajanje-granica": "border-collapse",
  "spajanje-rubina": "ruby-merge",
  "spoj-linije-udara": "stroke-linejoin",
  "sredina-markera": "marker-mid",
  "stanje-knjige": "bookmark-state",
  "stanje-reprodukcije-animacije": "animation-play-state",
  "stil-dekoracije-teksta": "text-decoration-style",
  "stil-desne-granice": "border-right-style",
  "stil-dna-granice": "border-bottom-style",
  "stil-fonta": "font-style",
  "stil-gornje-granice": "border-top-style",
  "stil-granice": "border-style",
  "stil-konture": "outline-style",
  "stil-lijeve-granice": "border-left-style",
  "stil-liste": "list-style",
  "stil-marquee": "marquee-style",
  "stil-naglaska-teksta": "text-emphasis-style",
  "stil-pravila-kolone": "column-rule-style",
  "stil-preljeva": "overflow-style",
  "stil-transformacije": "transform-style",
  "strana-markera": "marker-side",
  "strana-naslova": "caption-side",
  "stranica": "page",
  "stres": "stress",
  "stres-glasa": "voice-stress",
  "sve": "all",
  "svojstvo-prijelaza": "transition-property",
  "težina-fonta": "font-weight",
  "tip-maske": "mask-type",
  "tip-snimanja-scroll-a": "scroll-snap-type",
  "tip-stila-liste": "list-style-type",
  "točke-snimanja-scroll-a-x": "scroll-snap-points-x",
  "točke-snimanja-scroll-a-y": "scroll-snap-points-y",
  "trajanje-animacije": "animation-duration",
  "trajanje-glasa": "voice-duration",
  "trajanje-prijelaza": "transition-duration",
  "transformacija": "transform",
  "transformacija-teksta": "text-transform",
  "udar": "stroke",
  "udovice": "widows",
  "unicode-bidi": "unicode-bidi",
  "unutrašnjost-oblika": "shape-inside",
  "uvlačenje-teksta": "text-indent",
  "uzorak-markera": "marker-pattern",
  "vanjština-oblika": "shape-outside",
  "varijanta-fonta": "font-variant",
  "varijante-istocnoazijskog-fonta": "font-variant-east-asian",
  "varijante-velikih-slova-fonta": "font-variant-caps",
  "vektorski-efekt": "vector-effect",
  "veličina": "size",
  "veličina-fonta": "font-size",
  "veličina-maske": "mask-size",
  "veličina-okvira": "box-sizing",
  "veličina-pozadine": "background-size",
  "veličina-tabulatora": "tab-size",
  "vertikalna-orijentacija-glypha": "glyph-orientation-vertical",
  "vertikalno-poravnanje": "vertical-align",
  "vidljivost": "visibility",
  "vidljivost-stražnje-strane": "backface-visibility",
  "viseća-interpunkcija": "hanging-punctuation",
  "visina": "height",
  "visina-glasa": "voice-pitch",
  "visina-linije": "line-height",
  "visina-teksta": "text-height",
  "visina-tona": "pitch",
  "volumen": "volume",
  "z-indeks": "z-index",
  "znak-razdvajanja": "hyphenate-character",
  "zona-razdvajanja": "hyphenate-limit-zone",
  "širina": "width",
  "širina-desne-granice": "border-right-width",
  "širina-dna-granice": "border-bottom-width",
  "širina-gornje-granice": "border-top-width",
  "širina-granice": "border-width",
  "širina-ime": "ime-width",
  "širina-kolone": "column-width",
  "širina-konture": "outline-width",
  "širina-kutije-maske": "mask-box-width",
  "širina-lijeve-granice": "border-left-width",
  "širina-pravila-kolone": "column-rule-width",
  "širina-slike-granice": "border-image-width",
  "širina-udara": "stroke-width"
}
```

## Supported Values

```JSON
{
  "100": "100",
  "200": "200",
  "300": "300",
  "400": "400",
  "500": "500",
  "600": "600",
  "700": "700",
  "800": "800",
  "900": "900",
  "alias": "alias",
  "alternativno": "alternate",
  "alternativno-obrnuto": "alternate-reverse",
  "apsolutno": "absolute",
  "apsolutno-kolorimetrično": "absolute-colorimetric",
  "automatski": "auto",
  "bademova": "peachpuff",
  "bez-istorijskih-ligatura": "no-historical-ligatures",
  "bez-konteksta": "no-contextual",
  "bez-neobaveznih-ligatura": "no-discretionary-ligatures",
  "bez-sadržaja": "nocontent",
  "bez-zajedničkih-ligatura": "no-common-ligatures",
  "bež": "beige",
  "bijela": "white",
  "bijeladima": "whitesmoke",
  "biserno": "peru",
  "blijedoružičasta": "palevioletred",
  "blijedotirkizna": "paleturquoise",
  "blijedozlatna": "palegoldenrod",
  "blok": "block",
  "brojevi-linija": "lining-nums",
  "centar": "center",
  "cijan": "cyan",
  "crna": "black",
  "crtkan": "dashed",
  "crvena": "red",
  "crvenonarandžasta": "orangered",
  "desno": "right",
  "dole": "bottom",
  "dubokoplava": "deepskyblue",
  "dvostruk": "double",
  "fiksirano": "fixed",
  "geometrijska-preciznost": "geometricPrecision",
  "glatko": "smooth",
  "gore": "top",
  "grupa-kolona-tabele": "table-column-group",
  "grupa-naslova-tabele": "table-header-group",
  "grupa-podnožja-tabele": "table-footer-group",
  "grupa-redova-tabele": "table-row-group",
  "horizontalno": "horizontal",
  "hvata": "grabbing",
  "i-promijeni-veličinu": "e-resize",
  "indigoplavkasta": "indigo",
  "indijancrvena": "indianred",
  "invertiraj": "invert",
  "isječak": "clip",
  "iskrivljeno": "oblique",
  "ispuna": "fill",
  "istorijske-ligature": "historical-ligatures",
  "izbočina": "ridge",
  "iznad-linije": "overline",
  "jedno-veliko-slovo": "unicase",
  "ji-promijeni-veličinu": "se-resize",
  "jz-promijeni-veličinu": "sw-resize",
  "kaki": "khaki",
  "kamenasta": "royalblue",
  "kestenjasta": "maroon",
  "kolona": "column",
  "kolona-tabele": "table-column",
  "kontekstni-meni": "context-menu",
  "kontekstualno": "contextual",
  "kontrast": "contrast",
  "kopiraj": "copy",
  "koraci": "steps",
  "korak-kraj": "step-end",
  "korak-početak": "step-start",
  "kraj": "end",
  "križić": "crosshair",
  "kubna-bezier": "cubic-bezier",
  "kurziv": "italic",
  "labavo": "loose",
  "lakše": "lighter",
  "lanena": "linen",
  "lavanda": "lavender",
  "lavandacvijetna": "lavenderblush",
  "lijevo": "left",
  "limeta": "lime",
  "limun": "lemonchiffon",
  "linearni-rgb": "linear-rgb",
  "ljepljivo": "sticky",
  "ljubičasta": "violet",
  "losos": "salmon",
  "magenta": "magenta",
  "mala-slova": "lowercase",
  "mala-velika-slova": "small-caps",
  "malo": "small",
  "maslinasta": "olive",
  "maslinastozelena": "olivedrab",
  "medena": "honeydew",
  "mintkrem": "mintcream",
  "moccasin": "moccasin",
  "mornarska": "navy",
  "mornarskoplava": "navy",
  "morska": "seagreen",
  "mutnožuta": "dimgrey",
  "nad": "super",
  "napredak": "progress",
  "naprijed": "forwards",
  "narandžasta": "orange",
  "naslijedi": "inherit",
  "naslov-tabele": "table-caption",
  "naslovna-velika-slova": "titling-caps",
  "ne-ispusti": "no-drop",
  "ne-omotaj": "nowrap",
  "ne-ponavljaj": "no-repeat",
  "nebeska": "skyblue",
  "nema": "none",
  "neobavezne-ligature": "discretionary-ligatures",
  "nije-dopušteno": "not-allowed",
  "numerički": "numeric",
  "oba": "both",
  "obrnuta-kolona": "column-reverse",
  "obrnuti-omotaj": "wrap-reverse",
  "obrnuto": "reverse",
  "odvoji": "separate",
  "okruglo": "round",
  "okvir-granice": "border-box",
  "okvir-ispune": "padding-box",
  "okvir-margine": "margin-box",
  "okvir-pogleda": "view-box",
  "okvir-sadržaja": "content-box",
  "okvir-udara": "stroke-box",
  "olakšanje": "ease",
  "olakšanje-izlaz": "ease-out",
  "olakšanje-ulaz": "ease-in",
  "olakšanje-ulaz-izlaz": "ease-in-out",
  "omotaj": "wrap",
  "opravdaj": "justify",
  "optimiziraj-brzinu": "optimizeSpeed",
  "optimiziraj-kvalitet": "optimizeQuality",
  "osnovna-linija": "baseline",
  "osvjetljenje": "brightness",
  "oštri-rubovi": "crisp-edges",
  "pahuljastobijela": "mistyrose",
  "papajavipjenska": "papayawhip",
  "paradajz": "tomato",
  "pauzirano": "paused",
  "perceptivno": "perceptual",
  "piksilirano": "pixelated",
  "pjeskovita": "sandybrown",
  "plava": "blue",
  "plavapuder": "powderblue",
  "plavo-zeleno": "teal",
  "pod": "sub",
  "podebljanije": "bolder",
  "podebljano": "bold",
  "podvuci": "underline",
  "pokazivač": "pointer",
  "pokrij": "cover",
  "pomakni": "move",
  "pomoć": "help",
  "ponavljaj": "repeat",
  "ponavljaj-x": "repeat-x",
  "ponavljaj-y": "repeat-y",
  "poništi": "unset",
  "ponoćna": "midnightblue",
  "pozicija": "position",
  "početak": "start",
  "početno": "initial",
  "precrtana-nula": "slashed-zero",
  "precrtano": "line-through",
  "prelom-riječi": "break-word",
  "prelomi-prostore": "break-spaces",
  "preplanuo": "tan",
  "proljećnozelena": "springgreen",
  "promijeni-širinu-kolone": "col-resize",
  "proporcionalni-brojevi": "proportional-nums",
  "prostor": "space",
  "prostor-između": "space-between",
  "prostor-jednako": "space-evenly",
  "prostor-okolo": "space-around",
  "prozirna": "transparent",
  "prozirno": "transparent",
  "prozirnost": "opacity",
  "puna-veličina-kana": "full-size-kana",
  "puna-širina": "full-width",
  "pšenica": "wheat",
  "rastegnuti": "stretch",
  "red-tabele": "table-row",
  "redni": "ordinal",
  "relativno": "relative",
  "relativno-kolorimetrično": "relative-colorimetric",
  "rgb": "rgb",
  "rotiraj-nijansu": "hue-rotate",
  "roza": "pink",
  "ružičasta": "pink",
  "s-promijeni-veličinu": "n-resize",
  "sadrži": "contain",
  "savij": "flex",
  "sepija": "sepia",
  "si-promijeni-veličinu": "ne-resize",
  "siva": "grey",
  "sivo-skala": "grayscale",
  "sjena-ispod": "drop-shadow",
  "skriveno": "hidden",
  "skrolaj": "scroll",
  "slonovača": "ivory",
  "smanji": "scale-down",
  "smeđa": "brown",
  "smeđašipka": "rosybrown",
  "sniježna": "snow",
  "srebrna": "silver",
  "sredina": "middle",
  "srednje": "medium",
  "sruši": "collapse",
  "staračipka": "oldlace",
  "stari-stil-brojeva": "oldstyle-nums",
  "statika": "static",
  "sva-mala-velika-slova": "all-petite-caps",
  "sve-skrol": "all-scroll",
  "svijetlocijan": "lightcyan",
  "svijetlokamena": "lightslategrey",
  "svijetloljubičasta": "lightblue",
  "svijetloružičasta": "lightsalmon",
  "svijetlosiva": "lightpink",
  "svijetlosivkasta": "lightskyblue",
  "svijetlosmeđa": "lightbrown",
  "svijetlozelena": "lightsteelblue",
  "svijetlozlatna": "lightgoldenrodyellow",
  "svijetložuta": "lightyellow",
  "tabela": "table",
  "tamnobijela": "mediumorchid",
  "tamnocijan": "mediumcyan",
  "tamnokamena": "darkslategrey",
  "tamnolila": "mediumvioletred",
  "tamnoljubičasta": "darkslateblue",
  "tamnomagenta": "darkmagenta",
  "tamnomodra": "darkblue",
  "tamnonarandžasta": "darkorange",
  "tamnoplava": "mediumslateblue",
  "tamnoplavkasta": "mediumpurple",
  "tamnoproletna": "mediumspringgreen",
  "tamnoružičasta": "darkorchid",
  "tamnosea": "mediumseagreen",
  "tamnosiva": "darksalmon",
  "tamnotirkizna": "mediumturquoise",
  "tamnoviolet": "darkviolet",
  "tamnozelena": "darkturquoise",
  "tamnozelenkasta": "darkkhaki",
  "tamnozlatna": "darkgoldenrod",
  "tamnoškrletna": "darkred",
  "tekst": "text",
  "tirkizna": "turquoise",
  "točkast": "dotted",
  "tradicijskoroza": "thistle",
  "travnatoljubičasta": "lawngreen",
  "trenutna-boja": "currentColor",
  "treperi": "blink",
  "trotočka": "ellipsis",
  "u-liniji": "inline",
  "u-liniji-blok": "inline-block",
  "u-liniji-tabela": "inline-table",
  "u-toku": "running",
  "uhvati": "grab",
  "unutra": "inset",
  "uređaj-cmyk": "device-cmyk",
  "uređaj-n": "device-n",
  "uređaj-rgb": "device-rgb",
  "uređaj-siva": "device-gray",
  "velika-slova": "uppercase",
  "veliko": "large",
  "veliko-slovo": "capitalize",
  "vertikalni-tekst": "vertical-text",
  "vertikalno": "vertical",
  "veće": "larger",
  "vidljivo": "visible",
  "vrućeružičasta": "hotpink",
  "x-malo": "x-small",
  "x-veliko": "x-large",
  "xx-malo": "xx-small",
  "xx-veliko": "xx-large",
  "z-promijeni-veličinu": "w-resize",
  "zadano": "default",
  "zajedničke-ligature": "common-ligatures",
  "zasiti": "saturate",
  "zelena": "green",
  "zelenašipka": "steelblue",
  "zelenažuta": "navajowhite",
  "zelenkasta": "lime",
  "zelenkastašipka": "limegreen",
  "zlatna": "gold",
  "zlatnašipka": "goldenrod",
  "zumiraj-unutra": "zoom-in",
  "zumiraj-van": "zoom-out",
  "ćelija": "cell",
  "ćelija-tabele": "table-cell",
  "čekaj": "wait",
  "čvrst": "solid",
  "školjka": "seashell",
  "škrletna": "slategrey",
  "škrletnasta": "slateblue",
  "šljiva": "plum",
  "žlijeb": "groove",
  "žuta": "yellow",
  "žutašipka": "yellowgreen",
  "žutkastozelena": "greenyellow"
}

```
